@@ -24,15 +24,18 @@ import java.io.IOException;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
+import java.util.Map.Entry;
 import java.util.Properties;
 
+import org.apache.maven.shared.invoker.InvocationRequest.CheckSumPolicy;
+import org.apache.maven.shared.invoker.InvocationRequest.ReactorFailureBehavior;
 import org.codehaus.plexus.util.Os;
 import org.codehaus.plexus.util.StringUtils;
 import org.codehaus.plexus.util.cli.CommandLineUtils;
 import org.codehaus.plexus.util.cli.Commandline;
 
 /**
- * @version $Id: MavenCommandLineBuilder.java 1667628 2015-03-18 21:53:54Z rfscholte $
+ * @version $Id: MavenCommandLineBuilder.java 1760179 2016-09-10 14:49:13Z khmarbaise $
  */
 public class MavenCommandLineBuilder
 {
@@ -95,7 +98,7 @@ public class MavenCommandLineBuilder
         setSettingsLocation( request, cli );
 
         setToolchainsLocation( request, cli );
-        
+
         setProperties( request, cli );
 
         setProfiles( request, cli );
@@ -103,7 +106,7 @@ public class MavenCommandLineBuilder
         setGoals( request, cli );
 
         setThreads( request, cli );
-        
+
         return cli;
     }
 
@@ -148,7 +151,7 @@ public class MavenCommandLineBuilder
             cli.createArg().setValue( "-s" );
             cli.createArg().setValue( userSettingsFile.getPath() );
         }
-        
+
         File globalSettingsFile = request.getGlobalSettingsFile();
 
         if ( globalSettingsFile != null )
@@ -169,7 +172,7 @@ public class MavenCommandLineBuilder
         }
 
     }
-    
+
     protected void setToolchainsLocation( InvocationRequest request, Commandline cli )
     {
         File toolchainsFile = request.getToolchainsFile();
@@ -201,7 +204,8 @@ public class MavenCommandLineBuilder
             {
                 cli.addSystemEnvironment();
                 cli.addEnvironment( "MAVEN_TERMINATE_CMD", "on" );
-                // MSHARED-261: Ensure M2_HOME is not inherited, but gets a proper value
+                // MSHARED-261: Ensure M2_HOME is not inherited, but gets a
+                // proper value
                 cli.addEnvironment( "M2_HOME", getMavenHome().getAbsolutePath() );
             }
             catch ( IOException e )
@@ -271,9 +275,9 @@ public class MavenCommandLineBuilder
 
         if ( properties != null )
         {
-            for ( Iterator it = properties.entrySet().iterator(); it.hasNext(); )
+            for ( Iterator<Entry<Object, Object>> it = properties.entrySet().iterator(); it.hasNext(); )
             {
-                Map.Entry entry = (Map.Entry) it.next();
+                Entry<Object, Object> entry = it.next();
 
                 String key = (String) entry.getKey();
                 String value = (String) entry.getValue();
@@ -414,35 +418,19 @@ public class MavenCommandLineBuilder
     protected void setReactorBehavior( InvocationRequest request, Commandline cli )
     {
         // NOTE: The default is "fail-fast"
-        String failureBehavior = request.getFailureBehavior();
+        ReactorFailureBehavior failureBehavior = request.getReactorFailureBehavior();
 
-        if ( StringUtils.isNotEmpty( failureBehavior ) )
+        if ( failureBehavior != null )
         {
-            if ( InvocationRequest.REACTOR_FAIL_AT_END.equals( failureBehavior ) )
+            if ( ReactorFailureBehavior.FailAtEnd.equals( failureBehavior ) )
             {
-                cli.createArg().setValue( "-fae" );
+                cli.createArg().setValue( "-" + ReactorFailureBehavior.FailAtEnd.getShortOption() );
             }
-            else if ( InvocationRequest.REACTOR_FAIL_NEVER.equals( failureBehavior ) )
+            else if ( ReactorFailureBehavior.FailNever.equals( failureBehavior ) )
             {
-                cli.createArg().setValue( "-fn" );
+                cli.createArg().setValue( "-" + ReactorFailureBehavior.FailNever.getShortOption() );
             }
-        }
 
-        if ( request.isActivatedReactor() )
-        {
-            cli.createArg().setValue( "-r" );
-            String[] includes = request.getActivatedReactorIncludes();
-            String[] excludes = request.getActivatedReactorExcludes();
-            if ( includes != null )
-            {
-                cli.createArg().setValue( "-D" );
-                cli.createArg().setValue( "maven.reactor.includes=" + StringUtils.join( includes, "," ) );
-            }
-            if ( excludes != null )
-            {
-                cli.createArg().setValue( "-D" );
-                cli.createArg().setValue( "maven.reactor.excludes=" + StringUtils.join( excludes, "," ) );
-            }
         }
 
         if ( StringUtils.isNotEmpty( request.getResumeFrom() ) )
@@ -471,7 +459,7 @@ public class MavenCommandLineBuilder
 
     protected void setFlags( InvocationRequest request, Commandline cli )
     {
-        if ( !request.isInteractive() )
+        if ( request.isBatchMode() )
         {
             cli.createArg().setValue( "-B" );
         }
@@ -495,30 +483,36 @@ public class MavenCommandLineBuilder
         {
             cli.createArg().setValue( "-X" );
         }
-        // this is superceded by -X, if it exists.
+        // this is superseded by -X, if it exists.
         else if ( request.isShowErrors() )
         {
             cli.createArg().setValue( "-e" );
         }
 
-        String checksumPolicy = request.getGlobalChecksumPolicy();
-        if ( InvocationRequest.CHECKSUM_POLICY_FAIL.equals( checksumPolicy ) )
+        CheckSumPolicy checksumPolicy = request.getGlobalChecksumPolicy();
+        if ( CheckSumPolicy.Fail.equals( checksumPolicy ) )
         {
             cli.createArg().setValue( "-C" );
         }
-        else if ( InvocationRequest.CHECKSUM_POLICY_WARN.equals( checksumPolicy ) )
+        else if ( CheckSumPolicy.Warn.equals( checksumPolicy ) )
         {
             cli.createArg().setValue( "-c" );
         }
+
         if ( request.isNonPluginUpdates() )
         {
             cli.createArg().setValue( "-npu" );
         }
-        
+
         if ( request.isShowVersion() )
         {
             cli.createArg().setValue( "-V" );
         }
+
+        if ( request.getBuilder() != null )
+        {
+            cli.createArg().setValue( request.getBuilder() );
+        }
     }
 
     protected void setThreads( InvocationRequest request, Commandline cli )
@@ -529,7 +523,7 @@ public class MavenCommandLineBuilder
             cli.createArg().setValue( "-T" );
             cli.createArg().setValue( threads );
         }
-        
+
     }
 
     protected File findMavenExecutable()
@@ -588,9 +582,9 @@ public class MavenCommandLineBuilder
             {
                 executable = "mvn";
             }
-            
+
             mavenExecutable = new File( mavenHome, "/bin/" + executable );
-            
+
             try
             {
                 File canonicalMvn = mavenExecutable.getCanonicalFile();
@@ -610,25 +604,6 @@ public class MavenCommandLineBuilder
         return mavenExecutable;
     }
 
-    /**
-     * Wraps a path with quotes to handle paths with spaces. If no spaces are found, the original string is returned.
-     * 
-     * @param path string to wrap if containing spaces
-     * @return quote wrapped string
-     * @deprecated Quoting of command line arguments should be left to the Commandline from plexus-utils.
-     */
-    public String wrapStringWithQuotes( String path )
-    {
-        if ( path.indexOf( " " ) > -1 )
-        {
-            return "\"" + path + "\"";
-        }
-        else
-        {
-            return path;
-        }
-    }
-
     private Properties getSystemEnvVars()
         throws IOException
     {
@@ -681,7 +656,7 @@ public class MavenCommandLineBuilder
     }
 
     /**
-     * {@code mavenExecutable} can either be relative to ${maven.home}/bin/ or absolute 
+     * {@code mavenExecutable} can either be relative to ${maven.home}/bin/ or absolute
      * 
      * @param mavenExecutable the executable
      */
